@@ -9,7 +9,7 @@ use super::{property, PropertyType};
 /// The CONNACK packet is the packet sent by the Server in response to a CONNECT packet received from a Client.
 ///
 /// [MQTT5 Specification](https://docs.oasis-open.org/mqtt/mqtt/v5.0/os/mqtt-v5.0-os.html#_Toc3901074)
-#[derive(Debug, Clone, PartialEq)]
+#[derive(Debug, Clone, Eq, PartialEq, PartialOrd, Ord, Hash)]
 pub struct ConnAck<'a> {
     /// Position: bit 0 of the Connect Acknowledge Flags.
     ///
@@ -80,8 +80,8 @@ impl<'a> ConnAck<'a> {
     }
 
     fn len(&self) -> usize {
-        let mut len = 1  // sesssion present
-                        + 1; // code
+        // sesssion present + code
+        let mut len = 1 + 1;
 
         match &self.properties {
             Some(properties) => {
@@ -100,7 +100,7 @@ impl<'a> ConnAck<'a> {
 }
 
 /// [MQTT5 SPECIFICATION](https://docs.oasis-open.org/mqtt/mqtt/v5.0/os/mqtt-v5.0-os.html#_Toc3901080)
-#[derive(Debug, Clone, PartialEq, Default)]
+#[derive(Debug, Clone, Eq, PartialEq, PartialOrd, Ord, Hash, Default)]
 pub struct ConnAckProperties<'a> {
     /// `17 (0x11)` Byte, Identifier of the Session Expiry Interval.
     ///
@@ -487,7 +487,7 @@ impl<'a> ConnAckProperties<'a> {
 
 /// Return code in connack
 /// [MQTT5 SPECIFICATION](https://docs.oasis-open.org/mqtt/mqtt/v5.0/os/mqtt-v5.0-os.html#_Toc3901079)
-#[derive(Debug, Clone, Copy, PartialEq)]
+#[derive(Debug, Clone, Eq, PartialEq, PartialOrd, Ord, Hash, Copy)]
 #[repr(u8)]
 pub enum ConnectReasonCode {
     /// The Connection is accepted.
